@@ -45,8 +45,8 @@
 #include "kio_man.moc"
 #include "man2html.h"
 #include <assert.h>
+#include <kfilterbase.h>
 #include <kfilterdev.h>
-#include <QStandardPaths>
 
 using namespace KIO;
 
@@ -139,8 +139,8 @@ MANProtocol::MANProtocol(const QByteArray &pool_socket, const QByteArray &app_so
     section_names << "0" << "0p" << "1" << "1p" << "2" << "3" << "3n" << "3p" << "4" << "5" << "6" << "7"
                   << "8" << "9" << "l" << "n";
 
-    QString cssPath(QStandardPaths::locate(QStandardPaths::GenericDataLocation, "kio_docfilter/kio_docfilter.css" ));
-    QUrl cssUrl(QUrl::fromLocalFile(cssPath));
+    QString cssPath(KStandardDirs::locate( "data", "kio_docfilter/kio_docfilter.css" ));
+    KUrl cssUrl(KUrl::fromPath(cssPath));
     m_manCSSFile = cssUrl.url().toUtf8();
 }
 
@@ -449,7 +449,7 @@ extern void output_real(const char *insert)
 }
 #endif
 
-void MANProtocol::get(const QUrl& url )
+void MANProtocol::get(const KUrl& url )
 {
     kDebug(7107) << "GET " << url.url();
 
@@ -660,7 +660,7 @@ void MANProtocol::outputMatchingPages(const QStringList &matchingPages)
     finished();
 }
 
-void MANProtocol::stat( const QUrl& url)
+void MANProtocol::stat( const KUrl& url)
 {
     kDebug(7107) << "ENTERING STAT " << url.url();
 
@@ -696,7 +696,7 @@ void MANProtocol::stat( const QUrl& url)
 extern "C"
 {
 
-    int Q_DECL_EXPORT kdemain( int argc, char **argv ) {
+    int KDE_EXPORT kdemain( int argc, char **argv ) {
 
         KComponentData componentData("kio_man");
 
@@ -718,7 +718,7 @@ extern "C"
 
 }
 
-void MANProtocol::mimetype(const QUrl & /*url*/)
+void MANProtocol::mimetype(const KUrl & /*url*/)
 {
     mimeType("text/html");
     finished();
@@ -1353,7 +1353,7 @@ void MANProtocol::showIndex(const QString& section)
     finished();
 }
 
-void MANProtocol::listDir(const QUrl &url)
+void MANProtocol::listDir(const KUrl &url)
 {
     kDebug( 7107 ) << url;
 
@@ -1413,12 +1413,12 @@ void MANProtocol::getProgramPath()
   if (!mySgml2RoffPath.isEmpty())
     return;
 
-  mySgml2RoffPath = KStandardDirs::findExe("sgml2roff");
+  mySgml2RoffPath = KGlobal::dirs()->findExe("sgml2roff");
   if (!mySgml2RoffPath.isEmpty())
     return;
 
   /* sgml2roff isn't found in PATH. Check some possible locations where it may be found. */
-  mySgml2RoffPath = KStandardDirs::findExe("sgml2roff", QString(SGML2ROFF_DIRS));
+  mySgml2RoffPath = KGlobal::dirs()->findExe("sgml2roff", QString(SGML2ROFF_DIRS));
   if (!mySgml2RoffPath.isEmpty())
     return;
 
