@@ -528,7 +528,7 @@ bool sftpProtocol::sftpOpenConnection (const AuthInfo& info)
     return false;
   }
 
-  int timeout_sec = 30, timeout_usec = 0;
+  long timeout_sec = 30, timeout_usec = 0;
 
   kDebug(KIO_SFTP_DB) << "Creating the SSH session and setting options";
 
